use strictures 1;
use Test::More;
use IO::All;
use FindBin;
use File::Temp;
use lib "$FindBin::Bin/lib";
use aliased 'System::Introspector::Report::Publish::MediaWiki';

$ENV{TEST_SI_REPORT_OUT} = my $out_dir = File::Temp->newdir;
$ENV{TEST_SI_REPORT_IN}  = "$FindBin::Bin/data";

my %result;

my $wiki = MediaWiki->new(
  api_uri => 'http://example.com:9999/',
  connection_class => 'TestConnection',
  username => 'foo',
  password => 'bar',
  page => {
    foo => {
      report => ['foo:*'],
    },
  },
);

ok $wiki->publish([
  { id => [qw( foo a )],
    title => "Foo A",
    rowid => ['bar'],
    columns => [
      { key => 'bar', label => 'Bar' },
      { key => 'baz', label => 'Baz' },
    ],
    rows => [
      { bar => 231, baz => 421 },
      { bar => 232, baz => 884 },
      { bar => 332, baz => 784 },
    ],
  },
  { id => [qw( foo b )],
    title => "Foo B",
    rowid => ['bar'],
    columns => [
      { key => 'bar', label => 'Bar' },
      { key => 'baz', label => 'Baz' },
    ],
    rows => [
      { bar => 231, baz => 421 },
      { bar => 332, baz => 784 },
    ],
  },
  { id => [qw( foo c )],
    title => "Foo C",
    rowid => ['bar'],
    columns => [
      { key => 'bar', label => 'New Bar' },
      { key => 'baz', label => 'New Baz' },
    ],
    rows => [
      { bar => 232, baz => 884 },
      { bar => 332, baz => 784 },
      { bar => 989, baz => "foo\nbar" },
    ],
  },
]), 'publish ok';

my $_despace = sub {
  my $string = shift;
  $string =~ s{[\s\n]+}{}g;
  return $string;
};

## uncomment to regenerate result file
# do { no warnings; io("$out_dir/foo") > io("$FindBin::Bin/data/result/foo.txt"); fail "regenerated" };

is scalar(io("$out_dir/foo")->slurp)->$_despace,
   scalar(io("$FindBin::Bin/data/result/foo.txt")->slurp)->$_despace,
   'resulting page looks correct';

done_testing;
